Coverage for src/tests/test_lazy_evaluation.py: 100%

1 import remedapy as R

2 from tests.util import Spy

3

4

5 class TestLazyEvaluation:

6 def test_lazy_evaluation(self):

7 spy = Spy()

8 assert R.pipe([1, 2, 2, 3, 3, 4, 5, 6], R.tap(spy), R.unique(), R.take(3), list) == [1, 2, 3]

9 # assert spy.calls == [(1,), (2,), (3,)]

10 # there is something wrong with the example https://codeberg.org/Vulwsztyn/remedapy/issues/3

11 # (if you run it in js)